/* Using the counter and an interrupt for a simple timebase */

#include <avr/io.h>	      /* Defines pins, ports, etc */
#define F_CPU 8000000UL       /* Sets up the chip speed for delay.h */
#include <util/delay.h>	      /* Functions to waste time */
#define BAUDRATE  9600
#include "USART88.h"	       /* uses BAUDRATE, so define it first */
#include <avr/interrupt.h>
#include "pinDefines.h"
#include "commonInits.h"

volatile uint8_t hundredths;
volatile uint8_t seconds;
volatile uint8_t minutes = 15;
volatile uint8_t hours = 10;

ISR(TIMER0_COMPA_vect){		/* Happens ~100 times per second, so we keep it light */
  if(hundredths == 100){
    hundredths = 0;
    seconds++;
    if (seconds == 60){
      seconds = 0;
      minutes++;
      if (minutes == 60){
	minutes = 0;
	hours++;
	if (hours == 13){
	  hours = 1;
	}
      } 
    } 
  } 
  else{
    hundredths++;
  }
}

int main(void){

  uint8_t lastSecond;
  
  initLED();
  initUART();
  sayOK();
  
  /* Configure the timer */
  TCCR0A |= _BV(WGM01);		   /* CTC mode (p. 108, 106) */
  TCCR0B |= _BV(CS00) | _BV(CS02); /* Divide clock by 1024 (p. 110) */
  TIMSK0 |= _BV(OCIE0A);           /* output compare interrupt enable A (p. 111) */
  sei();			/* don't forget to enable interrupts! */
			
  /* 8,000,000 / 1024 = 7812.5 counts per second */
  /* So if we count up to 78, we'll get ~100 counts per second */
  /* Note: if you're doing this for real,  get a crystal with an 
     evenly-divisible-by 1024 frequency */
  OCR0A = 78;			/* count up to 78 */

  while(1){

    if (!(seconds == lastSecond)){ /* only do something when the seconds value changes */
      LED_TOGGLE;
      lastSecond = seconds;

      /* Optionally print out the time over serial */
      transmitByte((hours % 100)/10 + '0');
      transmitByte((hours % 10) + '0');
      transmitByte(':');
      transmitByte((minutes % 100)/10 + '0');
      transmitByte((minutes % 10) + '0');
      transmitByte(':');
      transmitByte((seconds % 100)/10 + '0');
      transmitByte((seconds % 10) + '0');
      transmitByte('\r');
      transmitByte('\n');
    }    
  }	     /* end while */
  return(1);			/* never reached */
}				/* end main */
